@@ -70,4 +70,8 @@ TEMP_UNITS = [
    "f",
    "c",
    "k"
-]
\ No newline at end of file
+]
+
+# Element/Compound Lists.
+STRONG_ACIDS = ['HCl', 'HNO3', 'H2SO4', 'HBr', 'HI', 'HClO4', 'HClO3']
+STRONG_BASES = ['LiOH', 'NaOH', 'KOH', 'RbOH', 'CsOH', 'Ca(OH)2', 'Sr(OH)2', 'Ba(OH)2']
\ No newline at end of file
